CREATE TABLE WAITLIST_TYPE (
  ID_WAITLIST_TYPE NUMBER,
  DESCRIPTION VARCHAR2(200 CHAR),
  INTERNAL_DESCRIPTION VARCHAR2(200 CHAR),
  ACTIVE VARCHAR2(1 CHAR),
  CONSTRAINT WAITLIST_TYPE_PK PRIMARY KEY (ID_WAITLIST_TYPE)
);

CREATE SEQUENCE WAITLIST_TYPE_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 100 NOCACHE NOORDER  NOCYCLE;

CREATE TABLE WAITLIST (
  ID_WAITLIST NUMBER NOT NULL,
  NNLOCATION_ID NUMBER,
  ID_LASTNIKA NUMBER,
  ID_PLOVILA NUMBER,
  ID_TYPE NUMBER,
  AREA VARCHAR2(10 CHAR),
  ID_PRIVEZ NUMBER,
  DATE_FROM DATE,
  DATE_TO DATE,
  STATUS NUMBER,
  DATE_CREATED DATE,
  USER_CREATED VARCHAR2(250 CHAR),
  CONSTRAINT WAITLIST_PK PRIMARY KEY (ID_WAITLIST),
  CONSTRAINT WAITLIST_WAITLIST_TYPE_FK FOREIGN KEY (ID_TYPE) REFERENCES WAITLIST_TYPE(ID_WAITLIST_TYPE),
  CONSTRAINT WAITLIST_KUPCI_FK FOREIGN KEY (ID_LASTNIKA) REFERENCES KUPCI(ID),
  CONSTRAINT WAITLIST_PLOVILA_FK FOREIGN KEY (ID_PLOVILA) REFERENCES PLOVILA(ID)
);

ALTER TABLE WAITLIST
ADD LENGTH_OF_STAY NUMBER;

CREATE INDEX IX_WAITLIST_ID_TYPE ON WAITLIST (ID_TYPE);
CREATE INDEX IX_WAITLIST_ID_LASTNIKA ON WAITLIST (ID_LASTNIKA);
CREATE INDEX IX_WAITLIST_ID_PLOVILA ON WAITLIST (ID_PLOVILA);

CREATE SEQUENCE WAITLIST_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;

CREATE OR REPLACE VIEW V_WAITLIST AS (
	SELECT W.ID_WAITLIST, W.NNLOCATION_ID, W.ID_LASTNIKA, W.ID_PLOVILA, W.ID_TYPE, W.AREA, W.ID_PRIVEZ, W.DATE_FROM, W.DATE_TO, W.LENGTH_OF_STAY, W.STATUS, W.DATE_CREATED, W.USER_CREATED,
  WT.DESCRIPTION AS TYPE_DESCRIPTION, P.IME AS BOAT_NAME, NO.OPIS AS AREA_DESCRIPTION, NP.N_PRIVEZA AS BERTH_DESCRIPTION,
  (CASE WHEN (SELECT VREDNOST FROM S_NASTAVITVE WHERE FILTER = 'MARINA' AND SEKCIJA = 'MARINA' AND NAZIV = 'ChangeFirstLastName') = '1' THEN (K.IME || ' ' || K.PRIIMEK) ELSE (K.PRIIMEK || ' ' || K.IME) END) AS OWNER
	FROM WAITLIST W
 	LEFT OUTER JOIN WAITLIST_TYPE WT ON WT.ID_WAITLIST_TYPE = W.ID_TYPE
  LEFT OUTER JOIN PLOVILA P ON P.ID = W.ID_PLOVILA
  LEFT OUTER JOIN KUPCI K ON K.ID = W.ID_LASTNIKA
  LEFT OUTER JOIN NNOBJEKT NO ON NO.SIFRA = W.AREA
  LEFT OUTER JOIN NNPRIVEZ NP ON NP.ID_PRIVEZ = W.ID_PRIVEZ 
);

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (1761, SYSDATE, '5.5', 1681, 'Waitlist')
;
